@@ -30,8 +30,8 @@
   your version.
 */
 
-#ifndef CONTACTEDITORCONTACT_KWIDGETLISTER_H
-#define CONTACTEDITORCONTACT_KWIDGETLISTER_H
+#ifndef CONTACTEDITORCONTACT_KWIDGETLISTER_P_H
+#define CONTACTEDITORCONTACT_KWIDGETLISTER_P_H
 
 #include <QWidget>
 
@@ -209,4 +209,4 @@ private:
     //@endcond
 };
 
-#endif /* _KWIDGETLISTER_H_ */
+#endif // CONTACTEDITORCONTACT_KWIDGETLISTER_P_H
